pub struct RegistrationClient {
pub(crate) client: Client,
}Expand description
Client for initializing a user account.
Fields
client: ClientImplementations
Sourceimpl RegistrationClient
impl RegistrationClient
Sourcepub fn seal_open_org_invite_data(
&self,
input: OpenOrgInvite,
) -> Result<SealedOpenOrgInvite, RegistrationError>
pub fn seal_open_org_invite_data( &self, input: OpenOrgInvite, ) -> Result<SealedOpenOrgInvite, RegistrationError>
Seals an OpenOrgInvite into a SealedOpenOrgInvite. The returned
sealed_data is safe to place on the verification-email link; the returned
high_entropy_secret must stay client-side.
Sourcepub fn unseal_open_org_invite_data(
&self,
sealed: SealedOpenOrgInvite,
) -> Result<OpenOrgInvite, RegistrationError>
pub fn unseal_open_org_invite_data( &self, sealed: SealedOpenOrgInvite, ) -> Result<OpenOrgInvite, RegistrationError>
Unseals a SealedOpenOrgInvite back into an OpenOrgInvite. Returns
RegistrationError::Crypto if the paired secret does not match the sealed payload or
the payload has been tampered with.
Sourceimpl RegistrationClient
impl RegistrationClient
Sourcepub async fn post_keys_for_jit_password_registration(
&self,
request: JitMasterPasswordRegistrationRequest,
) -> Result<JitMasterPasswordRegistrationResponse, RegistrationError>
pub async fn post_keys_for_jit_password_registration( &self, request: JitMasterPasswordRegistrationRequest, ) -> Result<JitMasterPasswordRegistrationResponse, RegistrationError>
Initializes a new cryptographic state for a user and posts it to the server; enrolls the user to master password unlock.
Sourceimpl RegistrationClient
impl RegistrationClient
Sourcepub async fn post_keys_for_key_connector_registration(
&self,
key_connector_url: String,
sso_org_identifier: String,
) -> Result<KeyConnectorRegistrationResult, RegistrationError>
pub async fn post_keys_for_key_connector_registration( &self, key_connector_url: String, sso_org_identifier: String, ) -> Result<KeyConnectorRegistrationResult, RegistrationError>
Initializes a new cryptographic state for a user and posts it to the server; enrolls the user to key connector unlock.
Sourceimpl RegistrationClient
impl RegistrationClient
Sourcepub async fn post_keys_for_tde_registration(
&self,
request: TdeRegistrationRequest,
) -> Result<TdeRegistrationResponse, RegistrationError>
pub async fn post_keys_for_tde_registration( &self, request: TdeRegistrationRequest, ) -> Result<TdeRegistrationResponse, RegistrationError>
Initializes a new cryptographic state for a user and posts it to the server; enrolls in admin password reset and finally enrolls the user to TDE unlock.
Sourceimpl RegistrationClient
impl RegistrationClient
Sourcepub async fn post_keys_for_user_password_registration(
&self,
request: UserMasterPasswordRegistrationRequest,
) -> Result<UserMasterPasswordRegistrationResponse, RegistrationError>
pub async fn post_keys_for_user_password_registration( &self, request: UserMasterPasswordRegistrationRequest, ) -> Result<UserMasterPasswordRegistrationResponse, RegistrationError>
Initializes new password-based cryptographic state for a user and posts the state to the server